@@ -144,16 +144,6 @@ class ResourceState(Enum):
     TERMINATED = "terminated"
 
 
-class SlurmAllocationState(Enum):
-    CREATING = "creating"
-    UPDATE_SCHEDULED = "update_scheduled"
-    UPDATING = "updating"
-    DELETION_SCHEDULED = "deletion_scheduled"
-    DELETING = "deleting"
-    OK = "ok"
-    ERRED = "erred"
-
-
 class PaymentProfileType(Enum):
     FIXED_PRICE = "fixed_price"
     MONTHLY_INVOICES = "invoices"
@@ -1850,6 +1840,25 @@ class WaldurClient(object):
 
             return resource, True
 
+    def activate_offering(self, offering_uuid: str):
+        """
+        Activate a marketplace offering by changing its state to Active
+        :param offering_uuid: UUID of the offering to activate
+        """
+        url = self._build_resource_url(
+            Endpoints.MarketplaceProviderOffering, offering_uuid, action="activate"
+        )
+        return self._post(url, valid_states=[200])
+
+    def delete_offering(self, offering_uuid: str):
+        """
+        Delete a marketplace offering
+        :param offering_uuid: UUID of the offering to delete
+        """
+        return self._delete_resource(
+            Endpoints.MarketplaceProviderOffering, offering_uuid
+        )
+
     def get_customer(self, identifier, filters=None):
         return self._get_resource(Endpoints.Customers, identifier, filters)
 
@@ -2401,49 +2410,9 @@ class WaldurClient(object):
     def list_slurm_allocations(self, filters=None):
         return self._query_resource_list(Endpoints.SlurmAllocations, filters)
 
-    def set_slurm_allocation_state(
-        self, marketplace_resource_uuid: str, state: SlurmAllocationState
-    ):
-        url = self._build_resource_url(
-            Endpoints.MarketplaceSlurmRemote,
-            marketplace_resource_uuid,
-            "set_state",
-        )
-        payload = {"state": state.value}
-        self._post(url, valid_states=[200], json=payload)
-
-    def set_slurm_allocation_backend_id(
-        self, marketplace_resource_uuid: str, backend_id: str
-    ):
-        url = self._build_resource_url(
-            Endpoints.MarketplaceSlurmRemote,
-            marketplace_resource_uuid,
-            "set_backend_id",
-        )
-        payload = {"backend_id": backend_id}
-        self._post(url, valid_states=[200], json=payload)
-
     def list_slurm_associations(self, filters=None):
         return self._query_resource_list(Endpoints.SlurmAssociations, filters)
 
-    def create_slurm_association(self, marketplace_resource_uuid: str, username: str):
-        url = self._build_resource_url(
-            Endpoints.MarketplaceSlurmRemote,
-            marketplace_resource_uuid,
-            "create_association",
-        )
-        payload = {"username": username}
-        return self._post(url, valid_states=[200, 201], json=payload)
-
-    def delete_slurm_association(self, marketplace_resource_uuid: str, username: str):
-        url = self._build_resource_url(
-            Endpoints.MarketplaceSlurmRemote,
-            marketplace_resource_uuid,
-            "delete_association",
-        )
-        payload = {"username": username}
-        return self._post(url, valid_states=[200], json=payload)
-
     def set_slurm_allocation_limits(
         self,
         marketplace_resource_uuid: str,
